@@ -1,4 +1,4 @@
 from signal_backtester.core.runner import SignalBacktester
 
 
-__all__ = ['SignalBacktester']
+__all__ = ["SignalBacktester"]
